@@ -21,7 +21,8 @@ L<Chj::NamespaceCleanAbove>, L<FP::Struct>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
