@@ -52,7 +52,8 @@ L<FP::Ops>, L<FP::Combinators>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
